import React, { useState } from 'react';
import { Button } from '@graphpolaris/shared/lib/components/buttons';
import { useDialogContext } from '@graphpolaris/shared/lib/components/layout/Dialog';
import { Input } from '@graphpolaris/shared/lib/components/inputs';

interface UserManagementContentProps {
  sessionId: string;
  onConfirm: () => void;
  onCancel: () => void;
}

interface ListItem {
  label: string;
  checked: boolean;
  children?: ListItem[];
}

export const UserManagementContent: React.FC<UserManagementContentProps> = ({ sessionId, onConfirm, onCancel }) => {
  const { setOpen } = useDialogContext();
  const [activeTab, setActiveTab] = useState<'users' | 'content' | null>('users');

  const handleCancel = () => {
    onCancel();
    setOpen(false);
  };

  const handleTabClick = (tab: 'users' | 'content') => {
    setActiveTab(tab); // Set the active tab
  };

  const [users, setUsers] = useState([
    {
      name: 'Mike. W',
      email: 'user1@example.com',
      organization: 'Acme Corp',
    },
    {
      name: 'Fiona. S',
      email: 'user2@example.com',
      organization: 'Tech Solutions',
    },
    {
      name: 'Frodo. B',
      email: 'user3@example.com',
      organization: 'Innovatech',
    },
  ]);

  const [editingIndex, setEditingIndex] = useState<number | null>(null);
  const [editedUser, setEditedUser] = useState({ name: '', email: '', organization: '' });

  const handleAddUser = () => {
    const newUser = { name: '', email: '', organization: '' };
    setUsers((prevUsers) => [...prevUsers, newUser]);
    setEditingIndex(users.length); // Enter edit mode for the new user
    setEditedUser(newUser); // Set edited user to the new user
  };

  const handleDeleteUser = (index: number) => {
    const updatedUsers = users.filter((_, i) => i !== index);
    setUsers(updatedUsers);
  };

  const handleEditUser = (index: number) => {
    setEditingIndex(index);
    setEditedUser(users[index]);
  };

  const handleSaveEdit = () => {
    if (editingIndex !== null) {
      const updatedUsers = users.map((user, index) => (index === editingIndex ? editedUser : user));
      setUsers(updatedUsers);
      setEditingIndex(null); // Exit edit mode
    }
  };

  const handleCancelEdit = () => {
    setEditingIndex(null); // Exit edit mode without saving
  };

  const handleInputChange = (nanmeOrigin: string, value: string) => {
    console.log(nanmeOrigin, value);
    setEditedUser((prev) => ({ ...prev, [nanmeOrigin]: value }));
  };

  // dummy content
  const [isChecked, setIsChecked] = useState<boolean>(false);

  const [listData, setListData] = useState<ListItem[]>([
    {
      label: 'Database',
      checked: false,
      children: [
        {
          label: 'View',
          checked: false,
        },
        { label: 'Switch DB', checked: false },
      ],
    },
    {
      label: 'Schema',
      checked: false,
      children: [
        {
          label: 'View',
          checked: false,
        },
        { label: 'Change layout', checked: false },
      ],
    },
    {
      label: 'Query',
      checked: false,
      children: [
        {
          label: 'View',
          checked: false,
        },
        { label: 'Delete', checked: false },
        { label: 'Run ML', checked: false },
      ],
    },
    {
      label: 'Alerting',
      checked: false,
      children: [
        {
          label: 'View',
          checked: false,
        },
      ],
    },
  ]);

  const handleCheckboxChange = (index: number, childIndex?: number) => {
    console.log('idx', index, childIndex);
    setListData((prevListData) => {
      const updatedListData = [...prevListData];
      if (childIndex !== undefined) {
        // Update child checkbox
        updatedListData[index].children![childIndex].checked = !updatedListData[index].children![childIndex].checked;
      } else {
        // Update parent checkbox
        updatedListData[index].checked = !updatedListData[index].checked;
      }
      return updatedListData;
    });
  };

  return (
    <div className="flex flex-col w-[50rem] h-[40rem]">
      <div className="flex-grow justify-center p-2 text-sm overflow-hidden text-ellipsis whitespace-nowrap">
        <h1 className="flex justify-center font-bold gap-x-1">
          <span>Manage Viewer permissions of</span> <span className="text-secondary-500">{sessionId}</span>
        </h1>
      </div>

      <div className="flex flex-row justify-center">
        <div className="border border-gray-300 rounded-tl-md rounded-bl-md">
          <Button
            variant={activeTab === 'users' ? 'solid' : 'ghost'}
            size="lg"
            label="Users"
            onClick={() => handleTabClick('users')}
            className="h-[3rem] min-w-[10rem] transition-transform duration-300 ease-in-out"
          />
        </div>
        <div className="border border-gray-300 rounded-tr-md rounded-br-md">
          <Button
            variant={activeTab === 'users' ? 'ghost' : 'solid'}
            size="lg"
            label="Content"
            onClick={() => handleTabClick('content')}
            className="h-[3rem] min-w-[10rem] transition-transform duration-300 ease-in-out"
          />
        </div>
      </div>
      <div className="flex flex-col items-center flex-grow mt-4">
        <div
          className={`w-full transition-all duration-300 ease-in-out ${
            activeTab === 'users' ? 'opacity-100 max-h-screen' : 'opacity-0 max-h-0'
          }`}
        >
          {activeTab === 'users' && (
            <div className="mt-2 w-full overflow-x-auto">
              <div className="flex justify-end mb-4">
                <Button variant="solid" size="md" label="Add User" onClick={handleAddUser} />
              </div>
              <table className="min-w-full bg-white border border-gray-300 rounded-md">
                <thead>
                  <tr className="bg-gray-100 border-b">
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Name</th>
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Mail</th>
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Organization</th>
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                  </tr>
                </thead>
                <tbody>
                  {users.map((user, index) => (
                    <tr key={index} className="border-b rounded-md">
                      <td className="px-6 py-4 text-sm text-gray-700">
                        {editingIndex === index ? (
                          <Input
                            type="text"
                            size="xs"
                            value={editedUser.name}
                            required={true}
                            onChange={(e) => handleInputChange('name', e)}
                          />
                        ) : (
                          user.name
                        )}
                      </td>
                      <td className="px-6 py-4 text-sm text-gray-700">
                        {editingIndex === index ? (
                          <Input type="text" value={editedUser.email} required={true} onChange={(e) => handleInputChange('email', e)} />
                        ) : (
                          user.email
                        )}
                      </td>
                      <td className="px-6 py-4 text-sm text-gray-700">
                        {editingIndex === index ? (
                          <Input
                            type="text"
                            value={editedUser.organization}
                            required={true}
                            onChange={(e) => handleInputChange('organization', e)}
                          />
                        ) : (
                          user.organization
                        )}
                      </td>
                      <td className="px-6 py-4 text-sm text-gray-700">
                        <div className="flex space-x-2">
                          {editingIndex === index ? (
                            <>
                              <Button variant="solid" size="sm" label="Save" onClick={handleSaveEdit} />
                              <Button variant="ghost" size="sm" label="Cancel" onClick={handleCancelEdit} />
                            </>
                          ) : (
                            <>
                              <Button
                                variant="ghost"
                                size="lg"
                                iconComponent={'icon-[ic--baseline-delete-outline]'}
                                className="text-danger-500"
                                onClick={() => handleDeleteUser(index)}
                              />
                              <Button
                                variantType="secondary"
                                variant="ghost"
                                size="lg"
                                iconComponent={'icon-[ic--baseline-mode-edit]'}
                                onClick={() => handleEditUser(index)}
                              />
                            </>
                          )}
                        </div>
                      </td>
                    </tr>
                  ))}
                </tbody>
              </table>
            </div>
          )}
        </div>
        <div
          className={`w-full transition-all duration-300 ease-in-out ${
            activeTab === 'content' ? 'opacity-100 max-h-screen' : 'opacity-0 max-h-0'
          }`}
        >
          {activeTab === 'content' && (
            <div className="flex justify-center">
              <ul className="mt-2">
                {listData.map((item, index) => (
                  <li key={index}>
                    <div>
                      <span className="font-bold">{item.label}</span>
                      {item.children && (
                        <ul className="ml-6">
                          {item.children.map((child, childIndex) => (
                            <li key={childIndex}>
                              <div>
                                <Input
                                  type="boolean"
                                  label={child.label}
                                  value={child.checked}
                                  onChange={() => handleCheckboxChange(index, childIndex)}
                                />
                              </div>
                            </li>
                          ))}
                        </ul>
                      )}
                    </div>
                  </li>
                ))}
              </ul>
            </div>
          )}
        </div>
      </div>

      <div className="flex justify-center p-2 mt-auto">
        <div className="flex space-x-4">
          <Button variant="outline" size="md" label="Cancel" onClick={handleCancel} />
          <Button variantType="primary" size="md" label="Confirm" onClick={onConfirm} />
        </div>
      </div>
    </div>
  );
};
